==> pal-0.0.1.tar.gz: lib/src/database/repository/project_repository.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:flutter/cupertino.dart';
import 'package:pal/src/database/adapter/page_entity_adapter.dart';
import 'package:pal/src/database/entity/page_entity.dart';
import 'package:pal/src/database/repository/base_repository.dart';
import 'package:pal/src/services/http_client/base_client.dart';

class ProjectRepository extends BaseHttpRepository {
  final PageEntityAdapter _adapter = PageEntityAdapter();

  ProjectRepository({@required HttpClient httpClient})
      : super(httpClient: httpClient);

  Future<PageEntity> createAppIcon(
    String projectId,
    Uint8List imageData,
    String imageType,
    DateTime imageDate,
  ) async {
    var result = await httpClient
        .multipartImage(
          'settings',
          fileData: imageData.toList(),
          imageType: imageType,
          fileFieldName: 'appicon',
          filename: 'appicon',
        )
        .timeout(Duration(seconds: 60))
        .catchError((onError) {
          throw 'ERROR_UPLOADING_APP_ICON';
        });
    var stream = result.stream.transform(utf8.decoder);
    var jsonResult = await stream.first;
    if (result.statusCode >= 300) {
      print(' reason : $jsonResult');
      throw 'ERROR_UPLOADING_APP_ICON';
    }
    return _adapter.parse(jsonResult);
  }

  Future<PageEntity> updateAppIcon(
    String projectId,
    Uint8List imageData,
    String imageType,
    DateTime imageDate,
  ) async {
    var result = await httpClient
        .multipartImage(
          'settings',
          fileData: imageData.toList(),
          imageType: imageType,
          fileFieldName: 'appicon',
          filename: 'appicon',
          httpMethod: 'PUT',
        )
        .timeout(Duration(seconds: 60))
        .catchError((onError) {
          throw 'ERROR_UPLOADING_APP_ICON';
        });
    var stream = result.stream.transform(utf8.decoder);
    var jsonResult = await stream.first;
    if (result.statusCode >= 300) {
      print(' reason : $jsonResult');
      throw 'ERROR_UPLOADING_APP_ICON';
    }
    return _adapter.parse(jsonResult);
  }

}

==> pal-2.0.1.tar.gz: lib/src/database/repository/project_repository.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:http/http.dart';
import 'package:pal/src/database/adapter/app_icon_entity.dart';
import 'package:pal/src/database/entity/app_icon_entity.dart';
import 'package:pal/src/database/repository/base_repository.dart';
import 'package:pal/src/services/http_client/base_client.dart';

class ProjectRepository extends BaseHttpRepository {
  final AppIconEntityAdapter _adapter = AppIconEntityAdapter();

  ProjectRepository({required HttpClient httpClient})
      : super(httpClient: httpClient);

  Future<AppIconEntity> createAppIcon(
    Uint8List imageData,
    String imageType,
  ) async {
    var result = await httpClient
        .multipartImage(
          'pal-business/editor/app-icon',
          fileData: imageData.toList(),
          imageType: imageType,
          fileFieldName: 'appIcon',
          filename: 'appIcon',
        )
        .timeout(Duration(seconds: 60))
        .catchError((onError) {
      throw 'ERROR_UPLOADING_APP_ICON';
    });
    var stream = result.stream.transform(utf8.decoder);
    var jsonResult = await stream.first;
    if (result.statusCode >= 300) {
      print(' reason : $jsonResult');
      throw 'ERROR_UPLOADING_APP_ICON';
    }
    return _adapter.parse(jsonResult);
  }

  Future<AppIconEntity> updateAppIcon(
    String? appIconId,
    Uint8List imageData,
    String imageType,
  ) async {
    var result = await httpClient
        .multipartImage(
          'pal-business/editor/app-icon/$appIconId',
          fileData: imageData.toList(),
          imageType: imageType,
          fileFieldName: 'appIcon',
          filename: 'appIcon',
        )
        .timeout(Duration(seconds: 60))
        .catchError((onError) {
      throw 'ERROR_UPLOADING_APP_ICON';
    });
    var stream = result.stream.transform(utf8.decoder);
    var jsonResult = await stream.first;
    if (result.statusCode >= 300) {
      print(' reason : $jsonResult');
      throw 'ERROR_UPLOADING_APP_ICON';
    }
    return _adapter.parse(jsonResult);
  }

  Future<AppIconEntity> getAppIcon() async {
    final Response response =
        await this.httpClient.get(Uri.parse('pal-business/editor/app-icon'));
    return this._adapter.parse(response.body);
  }
}
